@@ -3,14 +3,26 @@ import logging
 import os
 import subprocess
 from time import sleep
+import numpy as np
 
 logger = logging.getLogger(__name__)
 
 
-def ensure_metafits(data_dir, obs_id, metafits_file):
+def ensure_metafits(data_dir, obsid, metafits_file):
+    """Ensure that the metafits file is in the directory, if not download it.
+
+    Parameters
+    ----------
+    data_dir : `str`
+        The directory to check the metafits file is in.
+    obsid : `int`
+        The MWA Observation ID.
+    metafits_file : `str`
+        The metafits file name.
+    """
     # TODO: To get the actual ppds file should do this with obsdownload -o <obsID> -m
 
-    if not os.path.exists(metafits_file):
+    if not os.path.exists(os.path.join(data_dir, metafits_file)):
         logger.warning("{0} does not exists".format(metafits_file))
         logger.warning("Will download it from the archive. This can take a "
                       "while so please do not ctrl-C.")
@@ -18,7 +30,7 @@ def ensure_metafits(data_dir, obs_id, metafits_file):
                        "labelled as a ppd file this is not true.")
         logger.warning("This is hopefully a temporary measure.")
 
-        get_metafits = "wget http://ws.mwatelescope.org/metadata/fits?obs_id={0} -O {1}".format(obs_id, metafits_file)
+        get_metafits = "wget http://ws.mwatelescope.org/metadata/fits?obs_id={0} -O {1}".format(obsid, metafits_file)
         try:
             subprocess.call(get_metafits,shell=True)
         except:
@@ -33,34 +45,32 @@ def ensure_metafits(data_dir, obs_id, metafits_file):
     # in case --work_dir was specified in process_vcs call product_dir and data_dir
     # are the same and thus we will not perform the copy
     #data_dir = data_dir.replace(comp_config['base_data_dir'], comp_config['base_product_dir']) # being pedantic
-    if os.path.exists(data_dir) and not os.path.exists(metafits_file):
+    if os.path.exists(data_dir) and not os.path.exists("{}/{}".format(data_dir, metafits_file)):
         logger.info("Copying {0} to {1}".format(metafits_file, data_dir))
         from shutil import copy2
         copy2("{0}".format(metafits_file), "{0}".format(data_dir))
 
 
 def singles_source_search(ra, dec=None, box_size=50., params=None):
-    """
-    Used to find all obsids within a box around the source to make searching through obs_ids more efficient.
+    """Used to find all obsids within a box around the source to make searching through obs_ids more efficient.
 
-    singles_source_search(ra, dec=None, box_size=45.)
-    Parameters:
+    Parameters
     ----------
-    ra: float
+    ra : `float`
         Right Acension of the source in degrees
-    dec: float
+    dec : `float`
         Declination of the source in degrees. By default will use the enitre declination range to account for grating lobes
-    box_size: float
+    box_size : `float`
         Radius of the search box. Default: 45
-    params: dict
+    params : `dict`
         The dictionary of constraints used to search for suitable observations as explained here:
         https://wiki.mwatelescope.org/display/MP/Web+Services#WebServices-Findobservations
-        Default: {'mode':'VOLTAGE_START'}
+        |br| Default: {'mode':'VOLTAGE_START'}
 
-    Returns:
-    --------
-    obsid_metadata: list
-        List of the metadata for each obsid. The metadata is in the same format as getmeta's output
+    Returns
+    -------
+    obsid_list : `list`
+        List of the MWA observation IDs.
     """
     if params is None:
         # Load default params
@@ -98,36 +108,36 @@ def singles_source_search(ra, dec=None, box_size=50., params=None):
         params.update({'minra':ra_low,  'maxra':ra_high,
                        'mindec':dec_bot,'maxdec':dec_top})
     logger.debug("params: {}".format(params))
-    print("params: {}".format(params))
     obsid_list = find_obsids_meta_pages(params=params)
     return obsid_list
 
-def find_obsids_meta_pages(params=None):
-    """
-    Loops over pages for each page for MWA metadata calls
 
-    Parameters:
-    --------
-    params: dict
+def find_obsids_meta_pages(params=None, pagesize=50):
+    """Loops over pages for each page for MWA metadata calls
+
+    Parameters
+    ----------
+    params : `dict`
         The dictionary of constraints used to search for suitable observations as explained here:
         https://wiki.mwatelescope.org/display/MP/Web+Services#WebServices-Findobservations
-        Default: {'mode':'VOLTAGE_START'}
+        |br| Default: {'mode':'VOLTAGE_START'}
 
-    Returns:
-    --------
-    obsid_list: list
-        List of observation IDs.
+    Returns
+    -------
+    obsid_list : `list`
+        List of the MWA observation IDs.
     """
     if params is None:
         params = {'mode':'VOLTAGE_START'}
+    params["pagesize"] = pagesize
     obsid_list = []
-    temp =[]
+    temp = []
     page = 1
     #need to ask for a page of results at a time
-    while len(temp) == 200 or page == 1:
+    while len(temp) == pagesize or page == 1:
         params['page'] = page
         logger.debug("Page: {0}   params: {1}".format(page, params))
-        temp = getmeta(service='find', params=params)
+        temp = getmeta(service='find', params=params, retry_http_error=True)
         if temp is not None:
             # if there are non obs in the field (which is rare) None is returned
             for row in temp:
@@ -138,11 +148,16 @@ def find_obsids_meta_pages(params=None):
 
     return obsid_list
 
+
 def get_obs_array_phase(obsid):
-    """
-    For the input obsid will work out the observations array phase in the form
+    """For the input obsid will work out the observations array phase in the form
     of P1 for phase 1, P2C for phase 2 compact or P2E for phase to extended array
     and OTH for other.
+
+    Parameters
+    ----------
+    obsid : `int`
+        The MWA Observation ID.
     """
     phase_info = getmeta(service='con', params={'obs_id':obsid, 'summary':''})
 
@@ -160,18 +175,31 @@ def get_obs_array_phase(obsid):
 
 
 def mwa_alt_az_za(obsid, ra=None, dec=None, degrees=False):
-    """
-    Calculate the altitude, azumith and zenith for an obsid
+    """Calculate the altitude, azumith and zenith for an obsid
 
-    Args:
-        obsid  : The MWA observation id (GPS time)
-        ra     : The right acension in HH:MM:SS
-        dec    : The declintation in HH:MM:SS
-        degrees: If true the ra and dec is given in degrees (Default:False)
+    Parameters
+    ----------
+    obsid : `int`
+        The MWA Observation ID.
+    ra : `str`
+        The Right Acension in the format "HH:MM:SS.SS".
+    dec : `str`
+        The Declination in the format "DD:MM:SS.SS".
+    degrees : `boolean`
+        If `True` the ra and dec is given in degrees. |br| Default: `False`.
+
+    Returns
+    -------
+    Alt : `float`
+        The altitude angle in degrees.
+    Az : `float`
+        The azimuth angle in degrees.
+    Za : `float`
+        The zenith angle in degrees.
     """
     from astropy.utils import iers
     iers.IERS_A_URL = 'https://datacenter.iers.org/data/9/finals2000A.all'
-    logger.debug(iers.IERS_A_URL)
+    #logger.debug(iers.IERS_A_URL)
 
     from astropy.time import Time
     from astropy.coordinates import SkyCoord, AltAz, EarthLocation
@@ -195,49 +223,91 @@ def mwa_alt_az_za(obsid, ra=None, dec=None, degrees=False):
     return Alt, Az, Za
 
 
-def get_common_obs_metadata(obsid, return_all=False, full_meta_data=None):
-    """
-    Gets needed common meta data from http://ws.mwatelescope.org/metadata/
+def get_common_obs_metadata(obsid, return_all=False, full_metadata=None):
+    """Gets needed common meta data from http://ws.mwatelescope.org/metadata/
 
-    Parameters:
-    -----------
-    obsid: int
-        The observation ID.
-    return_all: bool
-        OPTIONAL - If True will also return the full meta data dictionary. Default: False
-    full_meta_data: bool
-        OPTIONAL - The full meta data dictionary from getmeta. If this is not supplied will make the meta data call. Default: False.
+    Parameters
+    ----------
+    obsid : `int`
+        The MWA observation ID.
+    return_all : `boolean`, optional
+        If `True` will also return the full meta data dictionary. |br| Default: `False`.
+    full_metadata : `dict`, optional
+        The dictionary of metadata generated from :py:meth:`vcstools.metadb_utils.getmeta`
 
-    Returns:
-    --------
-    common_meta_data: list
+    Returns
+    -------
+    common_metadata : `list`
         [obsid, ra, dec, dura, [xdelays, ydelays], centrefreq, channels]
+
+        obsid : `int`
+            The MWA observation ID.
+        ra : `str`
+            The Right Acension in the format "HH:MM:SS.SS".
+        dec : `str`
+            The Declination in the format "DD:MM:SS.SS".
+        dura : `int`
+            The duration of the observation in seconds.
+        xdelays, ydelays : `list`
+            The analogue delays for each antena od the tile for both the x and y polarisations.
+        centrefreq : `float`
+            The centre observing frequency in MHz.
+        channels : `list`
+            The list of observing frequency coarse channel IDs.
     """
-    if full_meta_data is None:
+    if full_metadata is None:
         logger.info("Obtaining metadata from http://ws.mwatelescope.org/metadata/ for OBS ID: " + str(obsid))
-        full_meta_data = getmeta(service='obs', params={'obs_id':obsid})
-    ra = full_meta_data[u'metadata'][u'ra_pointing'] #in sexidecimal
-    dec = full_meta_data[u'metadata'][u'dec_pointing']
-    dura = full_meta_data[u'stoptime'] - full_meta_data[u'starttime'] #gps time
-    xdelays = full_meta_data[u'rfstreams'][u"0"][u'xdelays']
-    ydelays = full_meta_data[u'rfstreams'][u"0"][u'ydelays']
-    minfreq = float(min(full_meta_data[u'rfstreams'][u"0"][u'frequencies']))
-    maxfreq = float(max(full_meta_data[u'rfstreams'][u"0"][u'frequencies']))
-    channels = full_meta_data[u'rfstreams'][u"0"][u'frequencies']
+        full_metadata = getmeta(service='obs', params={'obs_id':obsid})
+    ra = full_metadata[u'metadata'][u'ra_pointing'] #in sexidecimal
+    dec = full_metadata[u'metadata'][u'dec_pointing']
+    dura = full_metadata[u'stoptime'] - full_metadata[u'starttime'] #gps time
+    xdelays = full_metadata[u'rfstreams'][u"0"][u'xdelays']
+    ydelays = full_metadata[u'rfstreams'][u"0"][u'ydelays']
+    minfreq = float(min(full_metadata[u'rfstreams'][u"0"][u'frequencies']))
+    maxfreq = float(max(full_metadata[u'rfstreams'][u"0"][u'frequencies']))
+    channels = full_metadata[u'rfstreams'][u"0"][u'frequencies']
     centrefreq = 1.28 * (minfreq + (maxfreq-minfreq)/2)
 
     if return_all:
-        return [obsid, ra, dec, dura, [xdelays, ydelays], centrefreq, channels], full_meta_data
+        return [obsid, ra, dec, dura, [xdelays, ydelays], centrefreq, channels], full_metadata
     else:
         return [obsid, ra, dec, dura, [xdelays, ydelays], centrefreq, channels]
 
 
-def getmeta(servicetype='metadata', service='obs', params=None, retries=3):
-    """
-    Function to call a JSON web service and return a dictionary:
-    Given a JSON web service ('obs', find, or 'con') and a set of parameters as
-    a Python dictionary, return a Python dictionary xcontaining the result.
-    Taken verbatim from http://mwa-lfd.haystack.mit.edu/twiki/bin/view/Main/MetaDataWeb
+def getmeta(servicetype='metadata', service='obs', params=None, retries=3, retry_http_error=False):
+    """Function to call a JSON web service to perform an MWA metadata call.
+    Taken verbatim from http://mwa-lfd.haystack.mit.edu/twiki/bin/view/Main/MetaDataWeb.
+
+    Parameters
+    ----------
+    servicetype : `str`
+        Either the 'observation' which makes human readable html pages or 'metadata' which returns data.
+        |br| Default: metadata.
+    service : `str`
+        The meta data service from (Defaul: obs):
+
+        obs:
+            Returns details about a single observation as explained in
+            https://wiki.mwatelescope.org/display/MP/Web+Services#WebServices-Getobservation/scheduledataforanobservation
+
+        find:
+            Search the database for observations that satisfy given criteria as explained in
+            https://wiki.mwatelescope.org/display/MP/Web+Services#WebServices-Findobservations
+
+        con:
+            Finds the configuration information for an observation as explained in
+            https://wiki.mwatelescope.org/display/MP/Web+Services#WebServices-Gettelescopeconfigurationforagivenobservation
+
+    params : `dict`
+        A dictionary of the options to use in the metadata call which is dependent on the `service`. Examples can be found
+        https://wiki.mwatelescope.org/display/MP/Web+Services#WebServices-Usingthegetmeta()function
+    retries : `int`, optional
+        The number of times to retry timeout errors.
+
+    Returns
+    -------
+    result : `dict`
+        The result for that service.
     """
     import urllib.request
     import json
@@ -261,7 +331,13 @@ def getmeta(servicetype='metadata', service='obs', params=None, retries=3):
             result = json.load(urllib.request.urlopen(BASEURL + servicetype + '/' + service + '?' + data))
         except urllib.error.HTTPError as err:
             logger.error("HTTP error from server: code=%d, response: %s" % (err.code, err.read()))
-            break
+            if retry_http_error:
+                logger.error("Waiting {} seconds and trying again".format(wait_time))
+                sleep(wait_time)
+                pass
+            else:
+                raise err
+                break
         except urllib.error.URLError as err:
             logger.error("URL or network error: %s" % err.reason)
             logger.error("Waiting {} seconds and trying again".format(wait_time))
@@ -275,23 +351,53 @@ def getmeta(servicetype='metadata', service='obs', params=None, retries=3):
     return result
 
 
-def get_files(obsid, files_meta_data=None):
-    """
-    Queries the metadata to find all the file names
+def get_ambient_temperature(obsid, full_metadata=None):
+    """Queries the metadata to find the ambient temperature of the MWA tiles in K.
+    If none recorded then assume 22.4 C.
 
-    Parameters:
-    -----------
-    obsid: str
-        The ID (gps time) of the observation you are querying
-    files_meta_data: dict
-        The output of the getmeta function with the data_files service.
-        This is an optional input that can be used if you just want to
-        extract the relevant info and save a metadata call
+    Parameters
+    ----------
+    obsid : `int`
+        The MWA observation ID.
+    full_metadata : `dict`, optional
+        The dictionary of metadata generated from :py:meth:`vcstools.metadb_utils.getmeta`.
 
-    Output:
+    Returns
     -------
-    files: list
-        A list of all the file names
+    t_0 : `float`
+        The ambient temperature of the MWA tiles in K.
+    """
+    if full_metadata is None:
+        logger.info("Obtaining metadata from http://ws.mwatelescope.org/metadata/ for OBS ID: " + str(obsid))
+        full_metadata = getmeta(service='obs', params={'obs_id':obsid})
+    ambient_temp_dict = full_metadata[u'bftemps']
+    logger.debug("ambient_temp_dict: {}".format(ambient_temp_dict))
+    temperature_list_raw = []
+    for tile_key in ambient_temp_dict:
+        temperature_list_raw.append(ambient_temp_dict[tile_key][-1])
+    # Remove Nones
+    temperature_list = [i for i in temperature_list_raw if i]
+    logger.debug("temperature_list: {}".format(temperature_list))
+    if len(temperature_list) == 0:
+        logger.warning("No ambient temperature recorded so assuming the yearly average of 22.4 C.")
+        temperature_list = [22.4]
+    return np.mean(temperature_list) + 273.15
+
+
+def get_files(obsid, files_meta_data=None):
+    """Queries the metadata to find all the file names.
+
+    Parameters
+    ----------
+    obsid : `int`
+        The MWA Observation ID.
+    full_metadata : `dict`, optional
+        The dictionary of metadata generated from :py:meth:`vcstools.metadb_utils.getmeta`
+
+    Returns
+    -------
+    files : `list`
+        A list of all the file names.
     """
     if files_meta_data is None:
         files_meta_data = getmeta(servicetype='metadata', service='data_files', params={'obs_id':str(obsid)})
@@ -300,19 +406,19 @@ def get_files(obsid, files_meta_data=None):
 
 
 def calc_ta_fwhm(freq, array_phase='P2C'):
-    """
-    Calculates the approximate FWHM of the tied array beam in degrees.
+    """Calculates the approximate FWHM of the tied-array beam in degrees.
 
-    Parameters:
-    -----------
-    freq: float
-        Frequency in MHz
-    array_phase: string
-        OPTIONAL - The different array phase (from P1, P2C, P2E) to work out the maximum baseline length. Default = 'P2C'
-    Returns:
-    --------
-    fwhm: float
-        FWHM in degrees
+    Parameters
+    ----------
+    freq : `float`
+        Frequency in MHz.
+    array_phase : `str`, optional
+        The different array phase (from P1, P2C, P2E) to work out the maximum baseline length. |br| Default = 'P2C'.
+
+    Returns
+    -------
+    fwhm : `float`
+        FWHM in degrees.
     """
     from scipy.constants import c
     from math import degrees
@@ -335,35 +441,45 @@ def calc_ta_fwhm(freq, array_phase='P2C'):
 
 
 def get_channels(obsid, channels=None):
-    """
-    Gets the channels ids from the observation's metadata. If channels is not None assumes the
+    """Gets the channels ids from the observation's metadata. If channels is not None assumes the
     channels have already been aquired so it doesn't do an unnecessary database call.
+
+    Parameters
+    ----------
+    obsid : `int`
+        The MWA Observation ID.
+    channels : `list`, optional
+        The list of the coarse channel frequency IDs.
+
+    Returns
+    -------
+    channels : `list`
+        The list of the coarse channel frequency IDs.
     """
     if channels is None:
         print("Obtaining frequency channel data from http://mwa-metadata01.pawsey.org.au/metadata/"
               "for OBS ID: {}".format(obsid))
-        full_meta_data = getmeta(service='obs', params={'obs_id':obsid})
-        channels = full_meta_data[u'rfstreams'][u"0"][u'frequencies']
+        full_metadata = getmeta(service='obs', params={'obs_id':obsid})
+        channels = full_metadata[u'rfstreams'][u"0"][u'frequencies']
     return channels
 
 
 def obs_max_min(obsid, files_meta_data=None):
-    """
-    Small function to query the database and return the times of the first and last file
+    """Small function to query the database and return the times of the first and last file.
 
-    Parameters:
-    -----------
-    obsid: str
-        The ID (gps time) of the observation you are querying
-    files_meta_data: dict
-        The output of the getmeta function with the data_files service.
-        This is an optional input that can be used if you just want to
-        extract the relevant info and save a metadata call
+    Parameters
+    ----------
+    obsid : `int`
+        The MWA Observation ID.
+    full_metadata : `dict`, optional
+        The dictionary of metadata generated from :py:meth:`vcstools.metadb_utils.getmeta`
 
-    Output:
+    Returns
     -------
-    obs_start_end: list
-        [obs_start, obs_end]
+    obs_start : `int`
+        Beginning of the observation GPS time.
+    obs_end : `int`
+        End of the observation GPS time.
     """
     if files_meta_data is None:
         files_meta_data = getmeta(servicetype='metadata', service='data_files', params={'obs_id':str(obsid)})
@@ -380,22 +496,21 @@ def obs_max_min(obsid, files_meta_data=None):
 
 
 def files_available(obsid, files_meta_data=None):
-    """
-    Query the database and return a list of all files available (remote archived and not deleted) and a list of all files
+    """Query the database and return a list of all files available (remote archived and not deleted) and a list of all files
 
-    Parameters:
-    -----------
-    obsid: str
-        The ID (gps time) of the observation you are querying
-    files_meta_data: dict
-        The output of the getmeta function with the data_files service.
-        This is an optional input that can be used if you just want to
-        extract the relevant info and save a metadata call
+    Parameters
+    ----------
+    obsid : `int`
+        The MWA Observation ID.
+    full_metadata : `dict`, optional
+        The dictionary of metadata generated from :py:meth:`vcstools.metadb_utils.getmeta`
 
-    Output:
+    Returns
     -------
-    obs_start_end: list
-        [[list of available files], [all files]]
+    available_files : `list`
+        All files that have been archived and ready for download.
+    all_files : `list`
+        All files that are expected, once all files have been transfered/archived.
     """
     if files_meta_data is None:
         files_meta_data = getmeta(servicetype='metadata', service='data_files', params={'obs_id':str(obsid)})
@@ -413,53 +528,26 @@ def files_available(obsid, files_meta_data=None):
     return available_files, all_files
 
 
-def write_obs_info(obsid):
-    """
-    Writes obs info to a file in the current direcory
-    """
-    data_dict = getmeta(service='obs', params={'obs_id':str(obsid), 'nocache':1})
-    filename = str(obsid)+"_info.txt"
-    logger.info("Writing to file: {0}".format(filename))
-
-    channels = data_dict["rfstreams"]["0"]["frequencies"]
-    centre_freq = ( min(channels) + max(channels) ) / 2. * 1.28
-    array_phase = get_obs_array_phase(obsid)
-    start, stop = obs_max_min(obsid)
-
-    f = open(filename, "w+")
-    f.write("-------------------------    Obs Info    --------------------------\n")
-    f.write("Obs Name:           {}\n".format(data_dict["obsname"]))
-    f.write("Creator:            {}\n".format(data_dict["rfstreams"]["0"]["creator"]))
-    f.write("Array phase:        {}\n".format(array_phase))
-    if array_phase != 'OTH':
-        f.write("~FWHM (arcminute)   {:4.2f}\n".format(calc_ta_fwhm(centre_freq,
-                                                       array_phase=array_phase)*60.))
-    f.write("Start time:         {}\n".format(start))
-    f.write("Stop time:          {}\n".format(stop))
-    f.write("Duration (s):       {}\n".format(stop-start))
-    f.write("RA Pointing (deg):  {}\n".format(data_dict["metadata"]["ra_pointing"]))
-    f.write("DEC Pointing (deg): {}\n".format(data_dict["metadata"]["dec_pointing"]))
-    f.write("Channels:           {}\n".format(channels))
-    f.write("Centrefreq (MHz):   {}\n".format(centre_freq))
-    f.close()
-
-
 def get_best_cal_obs(obsid):
-    """
-    For the input MWA observation ID find all calibration observations within 2 days
+    """For the input MWA observation ID find all calibration observations within 2 days
     that have the same observing channels and list them from closest in time to furthest.
 
     Parameters
     ----------
-    obsid: int
-        The MWA observation ID (gps time)
+    obsid : `int`
+        The MWA Observation ID.
 
     Returns
     -------
-    cal_ids: list of lists
-        All calibration observations within 2 days that have the same observing channels and
-        list them from closest in time to furthest
+    cal_ids : `list`
         [[obsid, mins_away, cal_target]]
+
+        obsid : `int`
+            The MWA calibration observation ID.
+        mins_away : `float`
+            The mins away the calibration observation is away from the target observation.
+        cal_target : `str`
+            The calibration target name.
     """
     from operator import itemgetter
 
@@ -503,22 +591,21 @@ def get_best_cal_obs(obsid):
 
 
 def combined_deleted_check(obsid, begin=None, end=None):
-    """
-    Check if the combined files are deleted (or do not exist)
+    """Check if the combined files are deleted (or do not exist).
 
     Parameters
     ----------
-    obsid: int
-        The MWA observation ID (gps time)
-    begin: int
-        The begin GPS time to check (optional)
-    end:   int
-        The end GPS time to check (optional)
+    obsid : `int`
+        The MWA Observation ID.
+    beg : `int`, optional
+        Beginning of the observation GPS time to check.
+    end : `int`, optional
+        End of the observation GPS time to check.
 
     Returns
     -------
-    comb_del_check: bool
-        True if all combined files are deleted or if they do not exist
+    comb_del_check : `bool`
+        True if all combined files are deleted or if they do not exist.
     """
     # Work out the data_files metadata call parameters
     params = {'obs_id':obsid, 'nocache':1}
